<?php
/***************************************************************
*  Copyright notice
*
*  (c) 2003-2005 Gary (gniemcew@yahoo.com)
*  (c) 2006- Florian (florian.schlichting@gmx.de)
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

require_once PATH_tslib . 'class.tslib_pibase.php';

/**
 * Plugin 'Page HTTPS (SSL) Enforcer' for the 'https_enforcer' extension.
 *
 * This class represents a simple way to enforce the http|s protocoll on
 * a per page basis.
 *
 * History
 *
 * 2006-06-07 - Florian <florian.schlichting@gmx.de>
 * - use $_SERVER (available from PHP 4.1) instead of the
 *   depreciated $HTTP_SERVER_VARS [thanks, Johnny!]
 * - add always_allow_SSL option
 *
 * 2006-03-23 - Florian <florian.schlichting@gmx.de>
 * - make extension compatible with RealURL's directory-style URLs
 * - add ssl_proxy option
 * 
 * 2005-03-18 - Andreas Beutel <beutel@mehrwert.de>
 * - New option to disable enforcement for TYPO3 back end users
 * - Fix for the https://www.domain.tld/www.domain.tld bug
 * - Added comments/documentation to all functions
 *
 * 2004-09-09 - Michael Stucki <michael@typo3.org>
 * - Several updates and coding guidelines update (thanks!)
 * 
 * @author	Florian <florian.schlichting@gmx.de>
 * @author	Gary <gniemcew@yahoo.com>
 * @author	Michael Stucki <michael@typo3.org>
 * @author	Andreas Beutel <beutel@mehrwert.de>
 * @license	GPL
 */
class tx_httpsenforcer_pi1 extends tslib_pibase	{

	var $prefixId = 'tx_httpsenforcer_pi1';
	var $scriptRelPath = 'pi1/class.tx_httpsenforcer_pi1.php';
	var $extKey = 'https_enforcer';
	var $conf;

	/**
	 * The main function for this class; executed by TYPO3
	 *
	 * @param	string		Current content
	 * @param	array		Array with the configuration options
	 * @return	boolean		TRUE
	 * @access	public
	 */
	function main($content, $conf) {
		$this->conf = $conf;
		// 	check if http|s enforcment is enabled
		if ($this->conf['disable_httpsenforcer_for_be_user'] && $GLOBALS['BE_USER']->user) {
			// do nothing and return
		} else {
			// replace protocol and (un)secure_typo3_root
			if ($this->ext_requiresSSL() && !$this->ext_isSSL())	{
				$baseURI = explode($this->conf['unsecure_typo3_root'],t3lib_div::getIndpEnv('TYPO3_REQUEST_URL'));
				$ssl_proxy = ($this->conf['ssl_proxy']=='') ? '' : $this->conf['ssl_proxy'].'/';
				$url = 'https://'.$ssl_proxy.$this->conf['secure_typo3_root'].$baseURI[1];
				$this->ext_hardRedirect($url);
			} elseif (!$this->ext_requiresSSL() && $this->ext_isSSL() && !$this->conf['always_allow_SSL'])	{
				$baseURI = explode($this->conf['secure_typo3_root'],t3lib_div::getIndpEnv('TYPO3_REQUEST_URL'));
				$url = 'http://'.$this->conf['unsecure_typo3_root'].$baseURI[1];
				$this->ext_hardRedirect($url);
			}
		}
	}

	/**
	 * Check if the current page is already SSL encrypted
	 *
	 * This is done by checking the SERVER_PORT and HTTPS variables,
	 * unless we have configured an SSL-proxy, then HTTP_X_FORWARDED_SERVER is checked.
	 *
	 * @param	integer		Port number to check
	 * @return	boolean		TRUE if successful, FALSE otherwise
	 * @access	public
	 */
	function ext_isSSL($port = 443)	{
		if ($this->conf['ssl_proxy'] != '') {
			return (@$_SERVER['HTTP_X_FORWARDED_SERVER'] === $this->conf['ssl_proxy']);
		} elseif (@$_SERVER['SERVER_PORT'] != $port) {
			return false;
		} elseif (@$_SERVER['HTTPS'] != 'on')	{
			return false;
		} else {
			return true;
		}
	}

	/**
	 * Check if the current page does require SSL encryption
	 *
	 * @return	boolean		TRUE if SSL is required for this page, FALSE otherwise
	 * @access	public
	 */
	function ext_requiresSSL() {
		if($GLOBALS['TSFE']->page['tx_httpsenforcer_force_secure'] || $this->conf['require_ssl']) {
			return true;
		}
	}

	/**
	 * Send a redirect header
	 *
	 * @param	string		URL to redirect to
	 * @return	void
	 * @access	public
	 */
	function ext_hardRedirect($url)	{
		// header("HTTP 302 Redirect");
		header('Location: ' . $url);
		exit;
	}

}

if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/https_enforcer/pi1/class.tx_httpsenforcer_pi1.php']) {
	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/https_enforcer/pi1/class.tx_httpsenforcer_pi1.php']);
}

?>
